-- - prologDb2.ddl start ---------------------------------------------
-- Version: 1.1
-- -------------------------------------------------------------------
-- DDL for @PRODUCT.SERVER@ @PRODUCT.VERSION.DETAIL@ - @BLDLEVEL@
--
-- Create the IBM DB2 version of the Database tables.
--
-- DB2 8.1 Documentation:
-- http://www-306.ibm.com/software/data/db2/library/
-- - prologDb2.ddl end -----------------------------------------------
-- - dropTables.ddl start --------------------------------------------
-- Version: 1.6
-- -------------------------------------------------------------------
-- Drop the IBM IMS MDS MMS Database tables.
-- -------------------------------------------------------------------

DROP INDEX IDX_MMSNOTIFY1;
DROP INDEX IDX_MMSNOTIFY2;
DROP INDEX IDX_MMSNOTIFY3;
DROP INDEX IDX_MMSNOTIFY4;
DROP INDEX IDX_MMSNOTIFY5;
-- DROP INDEX IDX_MMSNOTIFY6;

DROP INDEX IDX_MMSRECEIVE1;
DROP INDEX IDX_MMSRECEIVE2;
DROP INDEX IDX_MMSRECEIVE3;

DROP INDEX IDX_MMSSEND1;
DROP INDEX IDX_MMSSEND2;
DROP INDEX IDX_MMSSEND3;
DROP INDEX IDX_MMSSEND4;
DROP INDEX IDX_MMSSEND5;

DROP SEQUENCE ASSIGNMENT_SEQ;
DROP SEQUENCE MESSAGEID_SEQ;

DROP TABLE MMSSENDDATA;
DROP TABLE MMSRECEIVEDATA;
DROP TABLE MMSNOTIFICATIONDATA;
-- - dropTables.ddl end ----------------------------------------------
CREATE TABLE MMSSENDDATA (
		TRANSACTIONID VARCHAR(250) NOT NULL,
		CREATETIME TIMESTAMP,
		EXPIRETIME TIMESTAMP,
		DELIVERYTIME TIMESTAMP,
		ASSIGNMENTID INTEGER NOT NULL,
		CHARGING VARCHAR(250),
		DESTINATION VARCHAR(250) NOT NULL,
		MESSAGEID VARCHAR(250),
		REQUESTER VARCHAR(250),
		SERVICE VARCHAR(250),
		CORRELATOR VARCHAR(250),
		DELIVERYSTATUS INTEGER NOT NULL,
		ATTRIBUTES VARCHAR(250),
		NETWORKID VARCHAR(250),
		ELEMENTID VARCHAR(250)
	)
	DATA CAPTURE NONE ;

CREATE TABLE MMSRECEIVEDATA (
		MESSAGEID BIGINT NOT NULL,
		CREATETIME TIMESTAMP,
		EXPIRETIME TIMESTAMP,
		NOTIFICATIONTRANSID VARCHAR(250) NOT NULL,
		MESSAGE VARCHAR(250),
		ATTRIBUTES VARCHAR(250),
		SENDER VARCHAR(250),
		DESTINATION VARCHAR(250),
		CORRELATOR VARCHAR(250),
		SERVICE VARCHAR(250),
		REQUESTER VARCHAR(250),
		MSGPRIORITY INTEGER,
		RETRIEVED SMALLINT
	)
	DATA CAPTURE NONE ;

CREATE TABLE MMSNOTIFICATIONDATA (
		TRANSACTIONID VARCHAR(250) NOT NULL,
		CREATETIME TIMESTAMP,
		EXPIRETIME TIMESTAMP,
		DESTINATION VARCHAR(250),
		CRITERIA VARCHAR(250),
		ENDPOINT VARCHAR(250),
		REQUESTER VARCHAR(250),
		SERVICE VARCHAR(250),
		CORRELATOR VARCHAR(250),
		ELEMENTID VARCHAR(250),
		ASSIGNMENTID INTEGER NOT NULL,
		ATTRIBUTES VARCHAR(250)
	)
	DATA CAPTURE NONE ;

ALTER TABLE MMSSENDDATA ADD CONSTRAINT PK_MMSSENDDATA PRIMARY KEY (TRANSACTIONID, DESTINATION);

ALTER TABLE MMSRECEIVEDATA ADD CONSTRAINT PK_MMSRECEIVEDATA PRIMARY KEY (MESSAGEID, NOTIFICATIONTRANSID);

ALTER TABLE MMSNOTIFICATIONDATA ADD CONSTRAINT PK_MMSNOTIFICATIO1 PRIMARY KEY (TRANSACTIONID);


-- - alterDb2.ddl start ---------------------------------------------
-- Version: 1.1
-- -------------------------------------------------------------------
-- Add additional indexes, views and constraints
-- Note: *** leave 1st line blank to compensate for tendency of
-- WSAD to generate a broken Table.ddl (no terminating newline on last line)
-- -------------------------------------------------------------------

-- MMSNOTIFICATIONDATA INDEXES BY FINDER
CREATE INDEX IDX_MMSNOTIFY1 ON MMSNOTIFICATIONDATA (CORRELATOR, SERVICE, REQUESTER);
CREATE INDEX IDX_MMSNOTIFY2 ON MMSNOTIFICATIONDATA (CORRELATOR, SERVICE);
CREATE INDEX IDX_MMSNOTIFY3 ON MMSNOTIFICATIONDATA (DESTINATION);
CREATE INDEX IDX_MMSNOTIFY4 ON MMSNOTIFICATIONDATA (ELEMENTID, ASSIGNMENTID);
CREATE INDEX IDX_MMSNOTIFY5 ON MMSNOTIFICATIONDATA (EXPIRETIME);
-- CREATE INDEX IDX_MMSNOTIFY6 ON MMSNOTIFICATIONDATA (TRANSACTIONID);

-- MMSRECEIVEDATA INDEXES BY FINDER
CREATE INDEX IDX_MMSRECEIVE1 ON MMSRECEIVEDATA (EXPIRETIME);
CREATE INDEX IDX_MMSRECEIVE2 ON MMSRECEIVEDATA (MESSAGEID, SERVICE, REQUESTER);
CREATE INDEX IDX_MMSRECEIVE3 ON MMSRECEIVEDATA (CORRELATOR, SERVICE, REQUESTER, MSGPRIORITY, EXPIRETIME, RETRIEVED);

-- MMSSENDDATA INDEXES BY FINDER
CREATE INDEX IDX_MMSSEND1 ON MMSSENDDATA (ASSIGNMENTID, DESTINATION);
CREATE INDEX IDX_MMSSEND2 ON MMSSENDDATA (TRANSACTIONID, DESTINATION, DELIVERYSTATUS);
CREATE INDEX IDX_MMSSEND3 ON MMSSENDDATA (EXPIRETIME);
CREATE INDEX IDX_MMSSEND4 ON MMSSENDDATA (TRANSACTIONID);
CREATE INDEX IDX_MMSSEND5 ON MMSSENDDATA (MESSAGEID, DESTINATION);

CREATE SEQUENCE ASSIGNMENT_SEQ AS INTEGER START WITH 1000 INCREMENT BY 1 CYCLE;
CREATE SEQUENCE MESSAGEID_SEQ AS BIGINT START WITH 1 INCREMENT BY 1 CYCLE;
COMMIT;
                 
-- - alterDb2.ddl end -----------------------------------------------
QUIT;
