-- - prologOra.ddl start ---------------------------------------------
-- Version: 1.1
-- -------------------------------------------------------------------
-- DDL for @PRODUCT.SERVER@ @PRODUCT.VERSION.DETAIL@ - @BLDLEVEL@
--
-- Create the Oracle version of the
-- IBM Telecom Web Services Server Database tables.
--
-- Oracle 9i2 Documentation (free registration required):
-- http://technet.oracle.com
-- -------------------------------------------------------------------
set linesize 2048
set pagesize 1024
set echo on
-- - prologOra.ddl end -----------------------------------------------
-- - dropTables.ddl start --------------------------------------------
-- Version: 1.6
-- -------------------------------------------------------------------
-- Drop the IBM IMS MDS MMS Database tables.
-- -------------------------------------------------------------------

DROP INDEX IDX_MMSNOTIFY1;
DROP INDEX IDX_MMSNOTIFY2;
DROP INDEX IDX_MMSNOTIFY3;
DROP INDEX IDX_MMSNOTIFY4;
DROP INDEX IDX_MMSNOTIFY5;
-- DROP INDEX IDX_MMSNOTIFY6;

DROP INDEX IDX_MMSRECEIVE1;
DROP INDEX IDX_MMSRECEIVE2;
DROP INDEX IDX_MMSRECEIVE3;

DROP INDEX IDX_MMSSEND1;
DROP INDEX IDX_MMSSEND2;
DROP INDEX IDX_MMSSEND3;
DROP INDEX IDX_MMSSEND4;
DROP INDEX IDX_MMSSEND5;

DROP SEQUENCE ASSIGNMENT_SEQ;
DROP SEQUENCE MESSAGEID_SEQ;

DROP TABLE MMSSENDDATA;
DROP TABLE MMSRECEIVEDATA;
DROP TABLE MMSNOTIFICATIONDATA;
-- - dropTables.ddl end ----------------------------------------------
CREATE TABLE MMSSENDDATA (
		TRANSACTIONID VARCHAR2(250) NOT NULL,
		CREATETIME DATE,
		EXPIRETIME DATE,
		DELIVERYTIME DATE,
		ASSIGNMENTID INT NOT NULL,
		CHARGING VARCHAR2(250),
		DESTINATION VARCHAR2(250) NOT NULL,
		MESSAGEID VARCHAR2(250),
		REQUESTER VARCHAR2(250),
		SERVICE VARCHAR2(250),
		CORRELATOR VARCHAR2(250),
		DELIVERYSTATUS INT NOT NULL,
		ATTRIBUTES VARCHAR2(250),
		NETWORKID VARCHAR2(250),
		ELEMENTID VARCHAR2(250)
	)
	LOGGING;

CREATE TABLE MMSRECEIVEDATA (
		MESSAGEID NUMBER(19 , 0) NOT NULL,
		CREATETIME DATE,
		EXPIRETIME DATE,
		NOTIFICATIONTRANSID VARCHAR2(250) NOT NULL,
		MESSAGE VARCHAR2(250),
		ATTRIBUTES VARCHAR2(250),
		SENDER VARCHAR2(250),
		DESTINATION VARCHAR2(250),
		CORRELATOR VARCHAR2(250),
		SERVICE VARCHAR2(250),
		REQUESTER VARCHAR2(250),
		MSGPRIORITY INT,
		RETRIEVED SMALLINT
	)
	LOGGING;

CREATE TABLE MMSNOTIFICATIONDATA (
		TRANSACTIONID VARCHAR2(250) NOT NULL,
		CREATETIME DATE,
		EXPIRETIME DATE,
		DESTINATION VARCHAR2(250),
		CRITERIA VARCHAR2(250),
		ENDPOINT VARCHAR2(250),
		REQUESTER VARCHAR2(250),
		SERVICE VARCHAR2(250),
		CORRELATOR VARCHAR2(250),
		ELEMENTID VARCHAR2(250),
		ASSIGNMENTID INT NOT NULL,
		ATTRIBUTES VARCHAR2(250)
	)
	LOGGING;

ALTER TABLE MMSSENDDATA ADD CONSTRAINT PK_MMSSENDDATA PRIMARY KEY (TRANSACTIONID, DESTINATION);

ALTER TABLE MMSRECEIVEDATA ADD CONSTRAINT PK_MMSRECEIVEDATA PRIMARY KEY (MESSAGEID, NOTIFICATIONTRANSID);

ALTER TABLE MMSNOTIFICATIONDATA ADD CONSTRAINT PK_MMSNOTIFICATIONDATA PRIMARY KEY (TRANSACTIONID);


-- - alterOra.ddl start ---------------------------------------------
-- Version: 1.1
-- -------------------------------------------------------------------
-- Add additional indexes, views and constraints
-- Note: *** leave 1st line blank to compensate for tendency of
-- WSAD to generate a broken Table.ddl (no terminating newline on last line)
-- -------------------------------------------------------------------

-- MMSNOTIFICATIONDATA INDEXES BY FINDER
CREATE INDEX IDX_MMSNOTIFY1 ON MMSNOTIFICATIONDATA (CORRELATOR, SERVICE, REQUESTER);
CREATE INDEX IDX_MMSNOTIFY2 ON MMSNOTIFICATIONDATA (CORRELATOR, SERVICE);
CREATE INDEX IDX_MMSNOTIFY3 ON MMSNOTIFICATIONDATA (DESTINATION);
CREATE INDEX IDX_MMSNOTIFY4 ON MMSNOTIFICATIONDATA (ELEMENTID, ASSIGNMENTID);
CREATE INDEX IDX_MMSNOTIFY5 ON MMSNOTIFICATIONDATA (EXPIRETIME);
-- CREATE INDEX IDX_MMSNOTIFY6 ON MMSNOTIFICATIONDATA (TRANSACTIONID);

-- MMSRECEIVEDATA INDEXES BY FINDER
CREATE INDEX IDX_MMSRECEIVE1 ON MMSRECEIVEDATA (EXPIRETIME);
CREATE INDEX IDX_MMSRECEIVE2 ON MMSRECEIVEDATA (MESSAGEID, SERVICE, REQUESTER);
CREATE INDEX IDX_MMSRECEIVE3 ON MMSRECEIVEDATA (CORRELATOR, SERVICE, REQUESTER, MSGPRIORITY, EXPIRETIME, RETRIEVED);

-- MMSSENDDATA INDEXES BY FINDER
CREATE INDEX IDX_MMSSEND1 ON MMSSENDDATA (ASSIGNMENTID, DESTINATION);
CREATE INDEX IDX_MMSSEND2 ON MMSSENDDATA (TRANSACTIONID, DESTINATION, DELIVERYSTATUS);
CREATE INDEX IDX_MMSSEND3 ON MMSSENDDATA (EXPIRETIME);
CREATE INDEX IDX_MMSSEND4 ON MMSSENDDATA (TRANSACTIONID);
CREATE INDEX IDX_MMSSEND5 ON MMSSENDDATA (MESSAGEID, DESTINATION);

CREATE SEQUENCE ASSIGNMENT_SEQ START WITH 1000 INCREMENT BY 1 MINVALUE 1000 MAXVALUE 2147483647 CYCLE;
CREATE SEQUENCE MESSAGEID_SEQ START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 CYCLE;
COMMIT;



QUIT;
